==> maven-helper-plugin-1.0.0-sources.jar: org/nuiton/license/plugin/LicensePlugin.java <==
/**
 * *##% Maven helper plugin
 * Copyright (C) 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>. ##%*
 */
package org.nuiton.license.plugin;

import org.nuiton.license.License;
import org.nuiton.license.LicenseFactory;

import java.io.File;
import org.apache.maven.project.MavenProject;

/**
 * Le goal pour ajouter le fichier LICENSE.txt dans le classpath (et le generer s'il n'existe pas).
 *
 * @author chemit
 * @goal add-license
 * @phase generate-resources
 * @requiresProject true
 * @requiresDependencyResolution compile
 */
public class LicensePlugin extends org.nuiton.AbstractPlugin {

    /**
     * Dependance du projet.
     *
     * @parameter default-value="${project}"
     * @required
     * @since 1.0.0
     */
    protected MavenProject project;
    /**
     * Fichier de la licence du module.
     *
     * @parameter expression="${helper.licenceFile}" default-value="${basedir}/LICENSE.txt"
     * @required
     * @readonly
     * @since 1.0.0
     */
    protected File licenseFile;
    /**
     * Le type de license a appliquer.
     *
     * @parameter expression="${license.licenseName}"
     * @required
     * @since 1.0.0
     */
    protected String licenseName;
    /**
     * Repertoire de sortie des sources.
     *
     * @parameter expression="${helper.outputDirectory}" default-value="target/generated-sources/resources"
     * @required
     * @since 1.0.0
     */
    protected File outputDirectory;
    /**
     * Repertoire de sortie des classes (classpath).
     *
     * @parameter expression="${helper.licenceFilename}" default-value=""
     * @since 1.0.0
     */
    protected String licenseFilename;
    /**
     * Encoding a utiliser pour lire et ecrire les fichiers.
     *
     * @parameter expression="${helper.encoding}" default-value="${project.build.sourceEncoding}"
     * @required
     * @since 1.0.0
     */
    protected String encoding;
    /**
     * Un flag pour conserver un backup des fichiers modifies.
     *
     * @parameter expression="${helper.keepBackup}"  default-value="false"
     * @since 1.0.0
     */
    protected boolean keepBackup;
    /**
     * Un flag pour forcer la generation.
     *
     * @parameter expression="${helper.force}"  default-value="false"
     * @since 1.0.0
     */
    protected boolean force;
    /**
     * Un flag pour activer le mode verbeux.
     *
     * @parameter expression="${helper.verbose}"  default-value="${maven.verbose}"
     * @since 1.0.0
     */
    protected boolean verbose;
    /**
     * Un flag pour farie une copie nommé dans META-INF (prefixe avec le nom de l'artifact).
     *
     * @parameter expression="${helper.copyToMETA_INF}"  default-value="false"
     * @since 1.0.0
     */
    protected boolean copyToMETA_INF;
    /**
     * La baseURL d'un resolver de license supplementaire
     *
     * @parameter expression="${helper.extraResolver}"
     * @since 1.0.0
     */
    protected String[] extraResolver;
    protected License license;

    public LicensePlugin() {
        super("all files are up-to-date.");
    }

    @Override
    protected boolean ensurePackaging() {
        return project != null && ("pom".equals(project.getPackaging()) || "site".equals(project.getPackaging()));
    }
    boolean doGenerate;

    @Override
    protected boolean init() throws Exception {

        // must generate if file does not exist
        doGenerate = true;

        if (!force) {
            // regenerate only if file exists and is newer than pom file
            doGenerate = !isFileNewerThanPomFile(licenseFile);
        }

        //if (doGenerate) {

        // acquire license

        LicenseFactory factory = LicenseFactory.newInstance(extraResolver);

        license = factory.revolv(licenseName);

        //}

        if (licenseFilename == null || licenseFilename.isEmpty()) {
            licenseFilename = licenseName;
        }
        return true;
    }

    @Override
    protected void doAction() throws Exception {
        getLog().info("using licence [" + licenseName + "]");

        if (doGenerate) {
            if (verbose) {
                getLog().info("detail : " + license);
            }

            if (licenseFile.exists() && keepBackup) {
                if (verbose) {
                    getLog().info("backup " + licenseFile);
                }
                // copy it to backup file
                File backup = new File(licenseFile.getAbsolutePath() + "~");
                licenseFile.renameTo(backup);
            }
        }

        String licenseContent = license.getLicenseContent(encoding);

        if (doGenerate) {
            copyFile(licenseContent, licenseFile, encoding);
        }

        // copy LICENSE.txt to classpath
        File target = new File(outputDirectory, licenseFile.getName());

        copyFile(licenseFile, target);

        if (copyToMETA_INF) {
            copyFile(licenseFile, new File(outputDirectory, "META-INF" + File.separator + project.getArtifactId() + "-" + licenseFile.getName()));
        }
        addResourceDir(outputDirectory.getAbsolutePath());

    }

    public File getLicenseFile() {
        return licenseFile;
    }

    public String getLicenseName() {
        return licenseName;
    }

    public License getLicense() {
        return license;
    }

    public String[] getExtraResolver() {
        return extraResolver;
    }

    public String getEncoding() {
        return encoding;
    }

    public boolean isKeepBackup() {
        return keepBackup;
    }

    public boolean isForce() {
        return force;
    }

    public File getOutputDirectory() {
        return outputDirectory;
    }

    public void setLicenseFile(File licenseFile) {
        this.licenseFile = licenseFile;
    }

    public void setLicenseName(String licenseName) {
        this.licenseName = licenseName;
    }

    public void setExtraResolver(String[] extraResolver) {
        this.extraResolver = extraResolver;
    }

    public void setLicense(License license) {
        this.license = license;
    }

    public void setEncoding(String encoding) {
        this.encoding = encoding;
    }

    public void setKeepBackup(boolean keepBackup) {
        this.keepBackup = keepBackup;
    }

    public void setOutputDirectory(File outputDirectory) {
        this.outputDirectory = outputDirectory;
    }

    public void setForce(boolean force) {
        this.force = force;
    }

    @Override
    public boolean isVerbose() {
        return verbose;
    }

    @Override
    public void setVerbose(boolean verbose) {
        this.verbose = verbose;
    }

    @Override
    public MavenProject getProject() {
        return project;
    }

    @Override
    public void setProject(MavenProject project) {
        this.project = project;
    }
}

==> maven-helper-plugin-1.0.2-sources.jar: org/nuiton/license/plugin/LicensePlugin.java <==
/*
 * *##% 
 * Maven helper plugin
 * Copyright (C) 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * ##%*
 */
package org.nuiton.license.plugin;

import org.nuiton.license.License;
import org.nuiton.license.LicenseFactory;

import java.io.File;
import org.apache.maven.project.MavenProject;

/**
 * Le goal pour ajouter le fichier LICENSE.txt dans le classpath (et le generer s'il n'existe pas).
 *
 * @author chemit
 * @goal add-license
 * @phase generate-resources
 * @requiresProject true
 * @requiresDependencyResolution compile
 */
public class LicensePlugin extends org.nuiton.AbstractPlugin {

    /**
     * Dependance du projet.
     *
     * @parameter default-value="${project}"
     * @required
     * @since 1.0.0
     */
    protected MavenProject project;
    /**
     * Fichier de la licence du module.
     *
     * @parameter expression="${helper.licenceFile}" default-value="${basedir}/LICENSE.txt"
     * @required
     * @readonly
     * @since 1.0.0
     */
    protected File licenseFile;
    /**
     * Le type de license a appliquer.
     *
     * @parameter expression="${license.licenseName}"
     * @required
     * @since 1.0.0
     */
    protected String licenseName;
    /**
     * Repertoire de sortie des sources.
     *
     * @parameter expression="${helper.outputDirectory}" default-value="target/generated-sources/resources"
     * @required
     * @since 1.0.0
     */
    protected File outputDirectory;
    /**
     * Repertoire de sortie des classes (classpath).
     *
     * @parameter expression="${helper.licenceFilename}" default-value=""
     * @since 1.0.0
     */
    protected String licenseFilename;
    /**
     * Encoding a utiliser pour lire et ecrire les fichiers.
     *
     * @parameter expression="${helper.encoding}" default-value="${project.build.sourceEncoding}"
     * @required
     * @since 1.0.0
     */
    protected String encoding;
    /**
     * Un flag pour conserver un backup des fichiers modifies.
     *
     * @parameter expression="${helper.keepBackup}"  default-value="false"
     * @since 1.0.0
     */
    protected boolean keepBackup;
    /**
     * Un flag pour forcer la generation.
     *
     * @parameter expression="${helper.force}"  default-value="false"
     * @since 1.0.0
     */
    protected boolean force;
    /**
     * Un flag pour activer le mode verbeux.
     *
     * @parameter expression="${helper.verbose}"  default-value="${maven.verbose}"
     * @since 1.0.0
     */
    protected boolean verbose;
    /**
     * Un flag pour faire une copie nommée dans META-INF (prefixe avec le nom de l'artifact).
     *
     * Cette option n'est utilisable que sur des modules avec un class-path (pas pour un pom)
     *
     * @parameter expression="${helper.copyToMETA_INF}"  default-value="false"
     * @since 1.0.0
     */
    protected boolean copyToMETA_INF;
    /**
     * La baseURL d'un resolver de license supplementaire
     *
     * @parameter expression="${helper.extraResolver}"
     * @since 1.0.0
     */
    protected String[] extraResolver;
    protected License license;

    public LicensePlugin() {
        super("all files are up-to-date.");
    }

    protected boolean hasClassPath() {
        return !("pom".equals(project.getPackaging()) || "site".equals(project.getPackaging()));
    }

    @Override
    protected boolean ensurePackaging() {
        return false;
//        return project != null && ("pom".equals(project.getPackaging()) || "site".equals(project.getPackaging()));
    }
    boolean doGenerate;

    @Override
    protected boolean init() throws Exception {

        // must generate if file does not exist
        doGenerate = true;

        if (!force) {
            // regenerate only if file exists and is newer than pom file
            doGenerate = !isFileNewerThanPomFile(licenseFile);
        }

        // acquire license

        LicenseFactory factory = LicenseFactory.newInstance(extraResolver);

        license = factory.revolv(licenseName);

        if (licenseFilename == null || licenseFilename.isEmpty()) {
            licenseFilename = licenseName;
        }
        return true;
    }

    @Override
    protected void doAction() throws Exception {
        getLog().info("using licence [" + licenseName + "]");

        if (doGenerate) {
            if (verbose) {
                getLog().info("detail : " + license);
            }

            if (licenseFile.exists() && keepBackup) {
                if (verbose) {
                    getLog().info("backup " + licenseFile);
                }
                // copy it to backup file
                File backup = new File(licenseFile.getAbsolutePath() + "~");
                licenseFile.renameTo(backup);
            }
        }

        String licenseContent = license.getLicenseContent(encoding);

        if (doGenerate) {
            copyFile(licenseContent, licenseFile, encoding);
        }

        if (hasClassPath()) {
            // copy LICENSE.txt to classpath
            File target = new File(outputDirectory, licenseFile.getName());

            copyFile(licenseFile, target);

            if (copyToMETA_INF) {
                copyFile(licenseFile, new File(outputDirectory, "META-INF" + File.separator + project.getArtifactId() + "-" + licenseFile.getName()));
            }
            addResourceDir(outputDirectory.getAbsolutePath());
        }
    }

    public File getLicenseFile() {
        return licenseFile;
    }

    public String getLicenseName() {
        return licenseName;
    }

    public License getLicense() {
        return license;
    }

    public String[] getExtraResolver() {
        return extraResolver;
    }

    public String getEncoding() {
        return encoding;
    }

    public boolean isKeepBackup() {
        return keepBackup;
    }

    public boolean isForce() {
        return force;
    }

    public File getOutputDirectory() {
        return outputDirectory;
    }

    public void setLicenseFile(File licenseFile) {
        this.licenseFile = licenseFile;
    }

    public void setLicenseName(String licenseName) {
        this.licenseName = licenseName;
    }

    public void setExtraResolver(String[] extraResolver) {
        this.extraResolver = extraResolver;
    }

    public void setLicense(License license) {
        this.license = license;
    }

    public void setEncoding(String encoding) {
        this.encoding = encoding;
    }

    public void setKeepBackup(boolean keepBackup) {
        this.keepBackup = keepBackup;
    }

    public void setOutputDirectory(File outputDirectory) {
        this.outputDirectory = outputDirectory;
    }

    public void setForce(boolean force) {
        this.force = force;
    }

    @Override
    public boolean isVerbose() {
        return verbose;
    }

    @Override
    public void setVerbose(boolean verbose) {
        this.verbose = verbose;
    }

    @Override
    public MavenProject getProject() {
        return project;
    }

    @Override
    public void setProject(MavenProject project) {
        this.project = project;
    }
}
